@@ -2,8 +2,8 @@
 run script to start server and celery task queue
 '''
 
-from utils import argParser
-from G_VAR import R_PATH
+from .utils import argParser
+from .G_VAR import R_PATH
 import os
 import subprocess
 
